FieldSubscription<T> class
A ControlSubscription that also implements StreamSubscription.
This is used by FieldControl to bridge the gap between the control framework's
subscription model and Dart's native Stream subscriptions.
- Inheritance
-
- Object
- ControlSubscription<
T> - FieldSubscription
- Implemented types
- Available extensions
Constructors
-
FieldSubscription(StreamSubscription<
T?> _sub)
Properties
- cancelOnError ↔ bool
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- isActive → bool
-
Checks is this subscription can serve.
no setteroverride
- isCallbackAttached → bool
-
Checks if callback to serve is available.
no setterinherited
- isPaused → bool
-
Whether the StreamSubscription is currently paused.
no setteroverride
- isValid → bool
-
Checks if observable is set.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
asFuture<
E> ([E? futureValue]) → Future< E> -
Returns a future that handles the onDone and onError callbacks.
override
-
cancel(
) → Future -
Cancels the subscription and removes it from the parent observable.
override
-
dispose(
) → void -
Releases resources used by the object.
override
-
disposeWith(
DisposeObserver observer) → void -
Available on Disposable, provided by the DisposableExt extension
Register for dispose with givenobserver. -
filter(
Predicate< T> ? filter) → ControlSubscription<T> -
Applies a filter to the subscription.
inherited
-
initSubscription(
ObservableValue parent, [ValueCallback< T> ? callback]) → void -
Activates the subscription by linking it to a parent observable and setting a callback.
inherited
-
invalidate(
) → void -
Marks the subscription as invalid, detaching it from its parent and callback.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyCallback(
T value) → void -
Notifies the subscription with a new value.
inherited
-
once(
) → ControlSubscription< T> -
Configures the subscription to be canceled after the first notification.
inherited
-
onData(
void handleData(T? data)?) → void -
Replaces the data event handler of this subscription.
override
-
onDone(
void handleDone()?) → void -
Replaces the done event handler of this subscription.
override
-
onError(
Function? handleError) → void -
Replaces the error event handler of this subscription.
override
-
pause(
[Future? resumeSignal]) → void -
Pauses the subscription, temporarily stopping notifications.
override
-
resume(
) → void -
Resumes a paused subscription.
override
-
toString(
) → String -
A string representation of this object.
inherited
-
until(
Predicate< T> ? predicate) → ControlSubscription<T> -
Sets a condition to automatically cancel the subscription.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited